@@ -1,6 +1,6 @@
 # Release information about submodal
 
-version = "1.4-2"
+version = "1.5"
 
 description = "Cross Browser DHTML Modal Dialogs For Web Apps"
 long_description = """\
@@ -9,12 +9,11 @@ access to the content below while still providing visibility. This maintains \
 state and doesn't make someone feel disoriented or lost by moving them \
 completely to another page. Their frame of reference is kept while allowing them \
 to perform a new task (usually closely associated with the content below). \
+\
+This version was based on the enhanced subModal provided by Todd Huss.\
 """
 author = "Jorge Godoy (packager)"
 email = "jgodoy@gmail.com"
-# copyright = "Vintage 2006 - a good year indeed"
 
-# if it's open source, you might want to specify these
-url = "http://sublog.subimage.com/articles/2006/01/01/subModal"
-# download_url = "http://yourcool.site/download"
+url = "http://gabrito.com/post/enhancements-to-submodal"
 license = "Free for any use - See included files"
